#=============================================================================
# GenerateAllScenes Class
#=============================================================================
require "SU_PodiumGenerateAllScenes/GenerateAllScenes"
require "FileUtils.rb"

#version 1.0.22006

class GenerateAllScenes

	def GenerateAllScenes.start()
		# Clear the selection so the selection boxes don't appear in the result
		Sketchup.active_model.selection.clear

		# Get the list of all pages (scenes), and the current page
		@@pageArray = Array.new
		Sketchup.active_model.pages.each {|page| @@pageArray << page.name}
		@@current_page = Sketchup.active_model.pages.selected_page

		GenerateAllBin.startUI();
		GenerateAllBin.setSceneNames(@@pageArray);
	end
	
	def GenerateAllScenes.SelectFolder

		@@path = UI.select_directory(title: "Select Output Directory")

		if(!@@path)
			@@path = File.dirname(Sketchup.active_model.path)
		end
		@model_name = File.basename(Sketchup.active_model.path, '.*')
   
        @model_name = "Untitled" if @model_name.empty?
        
		@@path += "/" + @model_name + "_Generate_All_"
		@@path += Time.now.strftime("_%m%d%Y%H%M%S")
	
		# create output folder if doesn't exists
		FileUtils.mkdir @@path if !File.exists?(@@path.to_s)

	end
	
	def GenerateAllScenes.EscapeCharacters(string)
		pattern = /(\'|\:|\>|\<|\"|\?|\*|\/|\\)/
		string.gsub(pattern){|match|"_"} 
	end
  
	def GenerateAllScenes.GenerateScene(index)

		@@renderer = Podium::Renderer.new
		sleepTime = 0.2
		#shadowinfo = Sketchup.active_model.shadow_info
		#if (shadowinfo["DisplayShadows"])
		#	sleepTime = 3
		#end
		
		allPages = Sketchup.active_model.pages
		Sketchup.active_model.pages.selected_page = allPages[index]

		# Pause as described above
		sleep sleepTime

		#generate script files
		@@renderer.generate(Sketchup.active_model,:path => @@path.to_s,:filename => EscapeCharacters(allPages[index].name.to_s))

	end
	
	# Script requires version 15 or higher.
	def GenerateAllScenes.version_15?
		version = Sketchup.version.to_i
		return true if ( version >= 15 )
	
		message = "GenerateAll: This program requires SketchUp 7 or later.\n"
		message += "You have SketchUp version #{ version }.\n"
		UI.messagebox( message, MB_OK, "SketchUp 7 Required")
		UI.beep
		return false
	end
	
	# Script requires podium::renderer (Podium V2 or higher).
	def GenerateAllScenes.podium_v2?
		if ((defined? Podium::Renderer) != nil )	# class exists
			check = Podium::Renderer.new
			if ( (defined? check.generate) != nil ) 		# method exists
				return true
			end
		end
		message = "GenerateAll: This program requires SU Podium V2 or later,\n"
		message += "available at http://www.su-podium.com.\n"
		UI.messagebox( message, MB_OK, "Podium V2 Required")
		UI.beep
		return false
	end
	
	# Script requires 1 or more pages in model.
	def GenerateAllScenes.nonEmpty?
		return true if ( Sketchup.active_model.pages.count() > 0 )
	
		message = "GenerateAll: No scenes in model.\n"
		UI.messagebox( message, MB_OK, "No scenes")
		UI.beep
		return false
	end
	
	def GenerateAllScenes.do_it
		#return unless ( GenerateAllScenes.version_15? )	# First let's make sure this is version 15
		return unless ( GenerateAllScenes.podium_v2? )	# Podium V2 or later loaded
		return unless ( GenerateAllScenes.nonEmpty? )	# Current model is non-empty
	
		GenerateAllScenes.start()
	end

end # class GenerateAllScenes


#=============================================================================
# Add to Plugins menu
#=============================================================================

if( not file_loaded?("SU_Podium_GenerateAllScenes.rb") )
  UI.menu("Plugins").add_item("Generate All") { GenerateAllScenes.do_it }
end

#-----------------------------------------------------------------------------
file_loaded("SU_Podium_GenerateAllScenes.rb")